@@ -22,7 +22,8 @@ LIBRARY_PATTERN = re.compile(r"(?:library|require)\([\"']?(.*)$")
 
 
 class RCompleter(Completer):
-    def __init__(self):
+    def __init__(self, timeout=0.02):
+        self.timeout = timeout
         super(RCompleter, self).__init__()
 
     def get_completions(self, document, complete_event):
@@ -45,11 +46,17 @@ class RCompleter(Completer):
 
     def get_r_completions(self, document, complete_event):
         text_before = document.current_line_before_cursor
+        completion_requested = complete_event.completion_requested
 
         with suppress_stderr():
             try:
                 token = rcompletion.assign_line_buffer(text_before)
-                rcompletion.complete_token()
+                # do not timeout package::func
+                if "::" in token or completion_requested:
+                    timeout = 0
+                else:
+                    timeout = self.timeout
+                rcompletion.complete_token(timeout)
                 completions = rcompletion.retrieve_completions()
             except Exception:
                 completions = []
